Module actor

Module actor 

Actor definitions, lifecycle results, and handles.

Structs

ActorHandle
A handle for observing an actor running in the cluster.
ActorHandleError
The worker stopped before reporting an actor’s exit.

Enums

ActorExit
The observed result of an actor task.

Traits

Actor
A single-threaded actor with serial access to its state.
Handler
Handles messages of type M for an actor.
Message
A message that can cross into an actor cluster.