pub struct Cluster { /* private fields */ }Expand description
A set of Compio workers on which actors are placed.
Implementations
Sourceimpl Cluster
impl Cluster
Sourcepub fn from_dispatcher(dispatcher: Dispatcher) -> Self
pub fn from_dispatcher(dispatcher: Dispatcher) -> Self
Creates a cluster from a configured dispatcher.
Sourcepub fn spawn<A, F>(
&self,
factory: F,
arguments: A::Arguments,
) -> Spawn<'_, A, F>
pub fn spawn<A, F>( &self, factory: F, arguments: A::Arguments, ) -> Spawn<'_, A, F>
Configures an actor spawn operation.
The return type is a configurable future implementing IntoFuture.
See Spawn for detail.