pub struct Mailbox<A: Actor> { /* private fields */ }Expand description
A typed reference to an actor in a cluster.
Implementations
Sourceimpl<A: Actor> Mailbox<A>
impl<A: Actor> Mailbox<A>
Sourcepub fn send<M>(&self, message: M) -> Result<(), DeliverError<M>>
pub fn send<M>(&self, message: M) -> Result<(), DeliverError<M>>
Enqueues a message handled by this actor without waiting.
Sourcepub fn capacity(&self) -> NonZeroUsize
pub fn capacity(&self) -> NonZeroUsize
Returns the fixed mailbox capacity.