Cluster

Struct Cluster 

pub struct Cluster { /* private fields */ }
A set of Compio workers on which actors are placed.

Implementations

Source

impl Cluster

pub fn current() -> Self

Returns the cluster running the current actor.

Panics

Panics when called outside an actor managed by a cluster.

pub fn try_current() -> Option<Self>

Try to get the cluster running the current actor.

Source

impl Cluster

pub fn new() -> Result<Self>

Creates a cluster using the dispatcher’s defaults.

pub fn from_dispatcher(dispatcher: Dispatcher) -> Self

Creates a cluster from a configured dispatcher.

pub fn spawn<A, F>( &self, factory: F, arguments: A::Arguments, ) -> Spawn<'_, A, F>
where A: Actor, F: FnOnce() -> A + Send + 'static,

Configures an actor spawn operation.

The return type is a configurable future implementing IntoFuture. See Spawn for detail.

pub fn lookup<A, N>(&self, name: N) -> Option<Mailbox<A>>
where A: Actor, N: Into<Cow<'static, str>>,

Looks up a named actor of type A.

pub async fn join(self) -> Result<()>

Stops the dispatcher workers and waits for their threads to exit.