pub trait Message: Send + 'static { }Expand description
A message that can cross into an actor cluster.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait Message: Send + 'static { }A message that can cross into an actor cluster.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".